<template>
  <div>
    <el-upload
        :action="uploadUrl"
        :headers="uploadHeaders"
        :show-file-list="false"
        :on-success="handleUploadSuccess"
        :before-upload="beforeUpload">
      <img v-if="fileUrl" :src="fileUrl" :style="getImgStyle()" class="avatar">
      <i v-else :style="getImgUploadIconStyle()" class="el-icon-plus avatar-uploader-icon"></i>
    </el-upload>
  </div>
</template>

<script>
export default {
  name: "UploadImg",
  props: {
    fileSizeLimitM: {
      required: false,
      default: 1,
      type: Number
    },
    imgWidth: {
      required: false,
      default: 178,
      type: Number
    },
    imgHeight: {
      required: false,
      default: 178,
      type: Number
    },
  },
  data() {
    return {
      uploadUrl: "/api/file/upload/no/expire",
      uploadHeaders: {
        'Authentication': sessionStorage.getItem("token")
      },
      fileUrl: "",
    }
  },
  methods: {
    setReviewUrl(url) {
      this.fileUrl = url
    },
    getImgUploadIconStyle() {
      return {
        width: `${this.imgWidth}px`,
        height: `${this.imgHeight}px`,
        lineHeight: `${this.imgHeight}px`,
      };
    },
    getImgStyle() {
      return {
        width: `${this.imgWidth}px`,
        height: `${this.imgHeight}px`,
      };
    },
    handleUploadSuccess(res, file) {
      this.fileUrl = file.response.data.url
      this.$emit('getUploadUrl', file.response.data.url);
    },
    beforeUpload(file) {
      const limit = file.size / 1024 / 1024 < this.fileSizeLimitM;

      if (!limit) {
        this.$message.error(`上传文件大小不能超过 ${this.fileSizeLimitM}MB!`);
      }
      return limit;
    },
  }
}
</script>

<style scoped>
.avatar-uploader {
  text-align: center;
  width: 100%
}
.avatar-uploader-icon:hover {
  border-color: #409EFF;
}
.avatar-uploader-icon {
  font-size: 28px;
  color: #8c939d;
  text-align: center;
  border: 1px dashed #d9d9d9;
  border-radius: 6px;
  cursor: pointer;

}
.avatar {
  display: block;
}
</style>
